@@ -346,7 +346,8 @@ def mbeep(repeat=1):
         cur.beep()
 
 def get_key(stdscr = None):
-    return stdscr.getch()
+    ch1 = stdscr.getch()
+    return ch1
 
 # -*- coding: utf-8 -*-
 import re
